GPULab CLI
==========

GPULab CLI is a CLI tool for submitting jobs to GPULab

Install with:

```shell
pip3 install imecilabt-gpulab-cli
```

Update to the latest version with:

```shell
pip3 install --upgrade imecilabt-gpulab-cli
```

GPULab users require an account at the [Fed4Fire Portal](https://portal.fed4fire.eu/)

Documentation and the version changelog for GPULab can be found at [the iLabt.t documentation site](https://doc.ilabt.imec.be/ilabt/gpulab/)

Send bugreports, questions and feedback to: **gpulab@ilabt.imec.be**

And/or use the [mattermost channel](https://mattermost.ilabt.imec.be/idlab/channels/gpulab-support)

You can see known bugs and feature requests at the [iLab.t GitLab](https://gitlab.ilabt.imec.be/ilabt/gpulab/issues)

References: 
- GPULab Site: https://gpulab.ilabt.imec.be/
- GPULab Documentation: https://doc.ilabt.imec.be/ilabt/gpulab/
- GPULab CLI Gitlab (currently private): https://gitlab.ilabt.imec.be/ilabt/gpulab/gpulab-cli
- PyPi: https://pypi.org/project/imecilabt-gpulab-cli/
